v0.2.0 (2022-10-25)
-------------------
- Update minimum pydantic version to 1.9
- Retry GraphQL requests that fail with 5xx errors
- Support Python 3.11
- Use `tomllib` on Python 3.11

v0.1.1 (2022-01-02)
-------------------
- Support tomli 2.0

v0.1.0 (2022-01-02)
-------------------
Initial release
